@@ -4,7 +4,6 @@ import signal
 import threading
 
 from scaled.scheduler.main import Scheduler
-from scaled.scheduler.worker_manager.vanilla import AllocatorType
 from scaled.utility.event_loop import EventLoopType, register_event_loop
 from scaled.utility.zmq_config import ZMQConfig
 from scaled.utility.logging.utility import setup_logger
@@ -15,23 +14,24 @@ stop_event = threading.Event()
 def get_args():
     parser = argparse.ArgumentParser("scaled scheduler", formatter_class=argparse.ArgumentDefaultsHelpFormatter)
     parser.add_argument(
-        "--worker-timeout-seconds", type=int, default=60, help="discard worker when timeout seconds " "reached"
+        "--worker-timeout-seconds", "-wt", type=int, default=60, help="discard worker when timeout seconds reached"
     )
     parser.add_argument(
         "--function-timeout-seconds",
+        "-ft",
         type=int,
         default=60,
         help="discard function in scheduler when timeout seconds " "reached",
     )
     parser.add_argument(
-        "--allocator-type",
-        required=True,
-        type=AllocatorType,
-        choices={t for t in AllocatorType},
-        help="specify allocator type",
+        "--per-worker-queue-size",
+        "-qs",
+        type=int,
+        default=1000,
+        help="specify per worker queue size",
     )
     parser.add_argument(
-        "--event-loop", default="builtin", choices=EventLoopType.allowed_types(), help="select event loop type"
+        "--event-loop", "-e", default="builtin", choices=EventLoopType.allowed_types(), help="select event loop type"
     )
     parser.add_argument("address", type=ZMQConfig.from_string, help="scheduler address to connect to")
 
@@ -47,7 +47,7 @@ def main():
     scheduler = Scheduler(
         address=args.address,
         stop_event=stop_event,
-        allocator_type=args.allocator_type,
+        per_worker_queue_size=args.per_worker_queue_size,
         worker_timeout_seconds=args.worker_timeout_seconds,
         function_timeout_seconds=args.function_timeout_seconds,
     )
